@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2012,2014,2015 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007-2012,2014-2016,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -54,7 +54,7 @@
 /**                # Version 5.1  : from : 30 nov 2007     **/
 /**                                 to   : 07 aug 2011     **/
 /**                # Version 6.0  : from : 12 sep 2008     **/
-/**                                 to     28 feb 2015     **/
+/**                                 to     10 jul 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -65,12 +65,6 @@
 **  The type and structure definitions.
 */
 
-/*+ Version flags. +*/
-
-#define SCOTCH_VERSION 6
-#define SCOTCH_RELEASE 0
-#define SCOTCH_PATCHLEVEL 4
-
 /*+ Integer type. +*/
 
 typedef int64_t SCOTCH_Idx;
@@ -80,35 +74,58 @@ typedef int SCOTCH_Num;
 #define SCOTCH_NUMMAX               ((int) (((unsigned int) 1 << ((sizeof (int) << 3) - 1)) - 1))
 #define SCOTCH_NUMSTRING            "%d"
 
+/*+ Version flags. +*/
+
+#if ((! defined SCOTCH_H_UNIQUE) && (! defined SCOTCH_RENAME_ALL))
+#define SCOTCH_VERSION 6
+#define SCOTCH_RELEASE 0
+#define SCOTCH_PATCHLEVEL 6
+#else /* ((! defined SCOTCH_H_UNIQUE) && (! defined SCOTCH_RENAME_ALL)) */
+#if ((SCOTCH_VERSION != 6) || (SCOTCH_RELEASE != 0) || (SCOTCH_PATCHLEVEL != 6))
+#ifndef SCOTCH_WARNING_RENAME_UNSAFE
+#define SCOTCH_WARNING_RENAME_UNSAFE
+#endif /* SCOTCH_WARNING_RENAME_UNSAFE */
+#endif /* ((SCOTCH_VERSION != 6) || (SCOTCH_RELEASE != 0) || (SCOTCH_PATCHLEVEL != 6)) */
+#endif /* SCOTCH_H_UNIQUE */
+
 /*+ Coarsening flags +*/
 
+#ifndef SCOTCH_COARSENNONE
 #define SCOTCH_COARSENNONE          0x0000
 #define SCOTCH_COARSENFOLD          0x0100
 #define SCOTCH_COARSENFOLDDUP       0x0300
 #define SCOTCH_COARSENNOMERGE       0x4000
+#endif /* SCOTCH_COARSENNONE */
 
 /*+ Strategy string parametrization values +*/
 
-#define SCOTCH_STRATDEFAULT         0x0000
-#define SCOTCH_STRATQUALITY         0x0001
-#define SCOTCH_STRATSPEED           0x0002
-#define SCOTCH_STRATBALANCE         0x0004
-#define SCOTCH_STRATSAFETY          0x0008
-#define SCOTCH_STRATSCALABILITY     0x0010
-#define SCOTCH_STRATRECURSIVE       0x0100
-#define SCOTCH_STRATREMAP           0x0200
-#define SCOTCH_STRATLEVELMAX        0x1000
-#define SCOTCH_STRATLEVELMIN        0x2000
-#define SCOTCH_STRATLEAFSIMPLE      0x4000
-#define SCOTCH_STRATSEPASIMPLE      0x8000
+#ifndef SCOTCH_STRATDEFAULT
+#define SCOTCH_STRATDEFAULT         0x00000
+#define SCOTCH_STRATQUALITY         0x00001
+#define SCOTCH_STRATSPEED           0x00002
+#define SCOTCH_STRATBALANCE         0x00004
+#define SCOTCH_STRATSAFETY          0x00008
+#define SCOTCH_STRATSCALABILITY     0x00010
+#define SCOTCH_STRATRECURSIVE       0x00100
+#define SCOTCH_STRATREMAP           0x00200
+#define SCOTCH_STRATLEVELMAX        0x01000
+#define SCOTCH_STRATLEVELMIN        0x02000
+#define SCOTCH_STRATLEAFSIMPLE      0x04000
+#define SCOTCH_STRATSEPASIMPLE      0x08000
+#define SCOTCH_STRATDISCONNECTED    0x10000
+#endif /* SCOTCH_STRATDEFAULT */
 
 /*+ Opaque objects. The dummy sizes of these
 objects, computed at compile-time by program
 "dummysizes", are given as double values for
 proper padding                               +*/
 
+#ifndef SCOTCH_H_UNIQUE
+typedef unsigned char       SCOTCH_GraphPart2;
+#endif /* SCOTCH_H_UNIQUE */
+
 typedef struct {
-  double                    dummy[8];
+  double                    dummy[11];
 } SCOTCH_Arch;
 
 typedef struct {
@@ -149,6 +166,8 @@ void                        SCOTCH_archExit     (SCOTCH_Arch * const);
 int                         SCOTCH_archLoad     (SCOTCH_Arch * const, FILE * const);
 int                         SCOTCH_archSave     (const SCOTCH_Arch * const, FILE * const);
 int                         SCOTCH_archBuild    (SCOTCH_Arch * const, const SCOTCH_Graph * const, const SCOTCH_Num, const SCOTCH_Num * const, const SCOTCH_Strat * const);
+int                         SCOTCH_archBuild0   (SCOTCH_Arch * const, const SCOTCH_Graph * const, const SCOTCH_Num, const SCOTCH_Num * const, const SCOTCH_Strat * const);
+int                         SCOTCH_archBuild2   (SCOTCH_Arch * const, const SCOTCH_Graph * const, const SCOTCH_Num, const SCOTCH_Num * const);
 char *                      SCOTCH_archName     (const SCOTCH_Arch * const);
 SCOTCH_Num                  SCOTCH_archSize     (const SCOTCH_Arch * const);
 int                         SCOTCH_archVar      (const SCOTCH_Arch * const);
@@ -157,9 +176,13 @@ int                         SCOTCH_archCmpltw   (SCOTCH_Arch * const, const SCOT
 int                         SCOTCH_archHcub     (SCOTCH_Arch * const, const SCOTCH_Num);
 int                         SCOTCH_archMesh2    (SCOTCH_Arch * const, const SCOTCH_Num, const SCOTCH_Num);
 int                         SCOTCH_archMesh3    (SCOTCH_Arch * const, const SCOTCH_Num, const SCOTCH_Num, const SCOTCH_Num);
+int                         SCOTCH_archMeshX    (SCOTCH_Arch * const, const SCOTCH_Num, const SCOTCH_Num * const);
+int                         SCOTCH_archSub      (SCOTCH_Arch * const, SCOTCH_Arch * const, const SCOTCH_Num, const SCOTCH_Num * const);
+
 int                         SCOTCH_archTleaf    (SCOTCH_Arch * const, const SCOTCH_Num, const SCOTCH_Num * const, const SCOTCH_Num * const);
 int                         SCOTCH_archTorus2   (SCOTCH_Arch * const, const SCOTCH_Num, const SCOTCH_Num);
 int                         SCOTCH_archTorus3   (SCOTCH_Arch * const, const SCOTCH_Num, const SCOTCH_Num, const SCOTCH_Num);
+int                         SCOTCH_archTorusX   (SCOTCH_Arch * const, const SCOTCH_Num, const SCOTCH_Num * const);
 int                         SCOTCH_archVcmplt   (SCOTCH_Arch * const);
 int                         SCOTCH_archVhcub    (SCOTCH_Arch * const);
 
@@ -179,14 +202,16 @@ void                        SCOTCH_graphFree    (SCOTCH_Graph * const);
 int                         SCOTCH_graphLoad    (SCOTCH_Graph * const, FILE * const, const SCOTCH_Num, const SCOTCH_Num);
 int                         SCOTCH_graphSave    (const SCOTCH_Graph * const, FILE * const);
 int                         SCOTCH_graphBuild   (SCOTCH_Graph * const, const SCOTCH_Num, const SCOTCH_Num, const SCOTCH_Num * const, const SCOTCH_Num * const, const SCOTCH_Num * const, const SCOTCH_Num * const, const SCOTCH_Num, const SCOTCH_Num * const, const SCOTCH_Num * const);
-int                         SCOTCH_graphCoarsen (const SCOTCH_Graph * const, SCOTCH_Graph * const, SCOTCH_Num * const, const SCOTCH_Num, const double);
-int                         SCOTCH_graphCoarsenBuild (const SCOTCH_Graph * const, SCOTCH_Graph * const, SCOTCH_Num * const, const SCOTCH_Num, SCOTCH_Num * const);
-int                         SCOTCH_graphColor   (const SCOTCH_Graph * const, SCOTCH_Num * const, SCOTCH_Num * const, const SCOTCH_Num);
-SCOTCH_Num                  SCOTCH_graphBase    (SCOTCH_Graph * const, const SCOTCH_Num baseval);
+SCOTCH_Num                  SCOTCH_graphBase    (SCOTCH_Graph * const, const SCOTCH_Num);
 int                         SCOTCH_graphCheck   (const SCOTCH_Graph * const);
-void                        SCOTCH_graphSize    (const SCOTCH_Graph * const, SCOTCH_Num * const, SCOTCH_Num * const);
+int                         SCOTCH_graphCoarsen (const SCOTCH_Graph * const, const SCOTCH_Num, const double, const SCOTCH_Num, SCOTCH_Graph * const, SCOTCH_Num * const);
+int                         SCOTCH_graphCoarsenMatch (const SCOTCH_Graph * const, SCOTCH_Num * const, const double, const SCOTCH_Num, SCOTCH_Num * const);
+int                         SCOTCH_graphCoarsenBuild (const SCOTCH_Graph * const, const SCOTCH_Num, SCOTCH_Num * const, SCOTCH_Graph * const, SCOTCH_Num * const);
+int                         SCOTCH_graphColor   (const SCOTCH_Graph * const, SCOTCH_Num * const, SCOTCH_Num * const, const SCOTCH_Num);
 void                        SCOTCH_graphData    (const SCOTCH_Graph * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num ** const, SCOTCH_Num ** const, SCOTCH_Num ** const, SCOTCH_Num ** const, SCOTCH_Num * const, SCOTCH_Num ** const, SCOTCH_Num ** const);
+void                        SCOTCH_graphSize    (const SCOTCH_Graph * const, SCOTCH_Num * const, SCOTCH_Num * const);
 void                        SCOTCH_graphStat    (const SCOTCH_Graph * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, double * const, double * const, SCOTCH_Num * const, SCOTCH_Num * const, double * const, double * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, double * const, double * const);
+SCOTCH_Num                  SCOTCH_graphDiamPV  (const SCOTCH_Graph * const);
 int                         SCOTCH_graphGeomLoadChac (SCOTCH_Graph * const, SCOTCH_Geom * const, FILE * const, FILE * const, const char * const);
 int                         SCOTCH_graphGeomLoadHabo (SCOTCH_Graph * const, SCOTCH_Geom * const, FILE * const, FILE * const, const char * const);
 int                         SCOTCH_graphGeomLoadMmkt (SCOTCH_Graph * const, SCOTCH_Geom * const, FILE * const, FILE * const, const char * const);
@@ -194,6 +219,8 @@ int                         SCOTCH_graphGeomLoadScot (SCOTCH_Graph * const, SCOT
 int                         SCOTCH_graphGeomSaveChac (const SCOTCH_Graph * const, const SCOTCH_Geom * const, FILE * const, FILE * const, const char * const);
 int                         SCOTCH_graphGeomSaveMmkt (const SCOTCH_Graph * const, const SCOTCH_Geom * const, FILE * const, FILE * const, const char * const);
 int                         SCOTCH_graphGeomSaveScot (const SCOTCH_Graph * const, const SCOTCH_Geom * const, FILE * const, FILE * const, const char * const);
+int                         SCOTCH_graphInduceList (const SCOTCH_Graph * const, const SCOTCH_Num, const SCOTCH_Num * const, SCOTCH_Graph * const);
+int                         SCOTCH_graphInducePart (const SCOTCH_Graph * const, const SCOTCH_Num, const SCOTCH_GraphPart2 * const, const SCOTCH_GraphPart2, SCOTCH_Graph * const);
 
 int                         SCOTCH_graphMapInit (const SCOTCH_Graph * const, SCOTCH_Mapping * const, const SCOTCH_Arch * const, SCOTCH_Num * const);
 void                        SCOTCH_graphMapExit (const SCOTCH_Graph * const, SCOTCH_Mapping * const);
@@ -266,6 +293,9 @@ int                         SCOTCH_numSizeof    (void);
 
 SCOTCH_Ordering *           SCOTCH_orderAlloc   (void);
 
+int                         SCOTCH_randomLoad   (FILE *);
+int                         SCOTCH_randomSave   (FILE *);
+void                        SCOTCH_randomProc   (int);
 void                        SCOTCH_randomReset  (void);
 void                        SCOTCH_randomSeed   (SCOTCH_Num);
 
@@ -291,4 +321,5 @@ void                        SCOTCH_version      (int * const, int * const, int *
 }
 #endif /* __cplusplus */
 
+#define SCOTCH_H_UNIQUE                           /* For symbols that need only be defined once */
 #endif /* SCOTCH_H */
